FunctionFsDescriptorsBuilder class

Builder for FunctionFs descriptor data.

Constructs the descriptor blob that must be written to FunctionFs ep0 before activating the gadget. Handles different USB speeds and feature flags.

Constructors

FunctionFsDescriptorsBuilder({FunctionFsMagic magic = FunctionFsMagic.v2})
Creates a new descriptor builder with v2 format by default.

Properties

flags FunctionFsFlags?
Optional flags for v2 format.
getter/setter pair
fullSpeed DescriptorSet?
Full-Speed descriptors (USB 1.1, 12 Mbps).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
highSpeed DescriptorSet?
High-Speed descriptors (USB 2.0, 480 Mbps).
getter/setter pair
magic FunctionFsMagic
FunctionFs format version (default: v2).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
superSpeed DescriptorSet?
SuperSpeed descriptors (USB 3.0, 5 Gbps).
getter/setter pair
superSpeedPlus DescriptorSet?
SuperSpeedPlus descriptors (USB 3.1+, 10+ Gbps).
getter/setter pair

Methods

build() FunctionFsDescriptors
Builds the FunctionFs descriptor data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited