FunctionFsMagic enum

Magic numbers for FunctionFs descriptor headers.

These identify the format version of the descriptor data written to FunctionFs. Different versions support different features and descriptor layouts.

The magic number is written as the first 4 bytes when writing descriptors to the FunctionFs ep0 file.

Inheritance
Available extensions

Values

v1 → const FunctionFsMagic

Original FunctionFs format (v1).

Basic descriptor support without flags or extended features. Magic: 0x00000001

const FunctionFsMagic(0x00000001)
strings → const FunctionFsMagic

Strings only format.

Magic: 0x00000002

const FunctionFsMagic(0x00000002)
v2 → const FunctionFsMagic

FunctionFs v2 format with flags.

Adds support for feature flags and SuperSpeed descriptors. Magic: 0x00000003

const FunctionFsMagic(0x00000003)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
The raw magic number value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int value) FunctionFsMagic?
Creates a magic number from its raw value.

Constants

values → const List<FunctionFsMagic>
A constant List of the values in this enum, in order of their declaration.