USBFeature enum
Standard USB feature selectors.
Values
- endpointHalt → const USBFeature
-
Endpoint halt feature (0x00).
const USBFeature(0x00) - deviceRemoteWakeup → const USBFeature
-
Device remote wakeup feature (0x01).
const USBFeature(0x01) - testMode → const USBFeature
-
Test mode feature (0x02).
const USBFeature(0x02) - intfFuncSuspend → const USBFeature
-
Interface function suspend feature (0x00).
const USBFeature(0x00)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
Raw feature value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
USBFeature> - A constant List of the values in this enum, in order of their declaration.